@@ -566,7 +566,7 @@ def find_peak_magnitude(
 ## AUTHOR : DRYX
 def generate_kcorrection_listing_database(
         log,
-        observeFrameFilter,
+        restFrameFilter,
         pathToOutputDirectory,
         pathToSpectralDatabase,
         temporalResolution=4.0,
@@ -577,7 +577,7 @@ def generate_kcorrection_listing_database(
 
     **Key Arguments:**
         - ``log`` -- logger
-        - ``observeFrameFilter`` -- the filter to generate the K-corrections against
+        - ``restFrameFilter`` -- the filter to generate the K-corrections against
         - ``pathToOutputDirectory`` -- path to the output directory (provided by the user)
         - ``pathToSpectralDatabase`` -- path to the directory containing the spectral database
         - ``temporalResolution`` -- temporal resolution at which to calculate the k-correcions
@@ -606,7 +606,10 @@ def generate_kcorrection_listing_database(
     generatedLCs = yaml.load(stream)
 
     ## REMOVE OLD DATABASE
-    shutil.rmtree(pathToOutputDirectory+"k_corrections")
+    try:
+        shutil.rmtree(pathToOutputDirectory+"k_corrections")
+    except:
+        pass
 
     models = generatedLCs.keys()
     for model in models:
@@ -620,7 +623,7 @@ def generate_kcorrection_listing_database(
                 pathToSpectralDatabase=pathToSpectralDatabase,
                 model=model,
                 redshift=redshift,
-                observeFrameFilter=observeFrameFilter,
+                restFrameFilter=restFrameFilter,
                 temporalResolution=4.0)
     return
 
@@ -633,7 +636,7 @@ def generate_single_kcorrection_listing(
         pathToOutputDirectory,
         pathToSpectralDatabase,
         model,
-        observeFrameFilter,
+        restFrameFilter,
         redshift,
         temporalResolution=4.0):
     """Given a redshift generate a dictionary of k-correction polynomials for the MCS.
@@ -643,7 +646,7 @@ def generate_single_kcorrection_listing(
         - ``pathToOutputDirectory`` -- path to the output directory (provided by the user)
         - ``pathToSpectralDatabase`` -- path to the directory containing the spectral database
         - ``model`` -- name of the object/model required
-        - ``observeFrameFilter`` -- the filter to generate the K-corrections against
+        - ``restFrameFilter`` -- the filter to generate the K-corrections against
         - ``redshift`` -- the redshift at which to generate the k-corrections for
         - ``temporalResolution`` -- temporal resolution at which to calculate the k-correcions
 
@@ -668,8 +671,8 @@ def generate_single_kcorrection_listing(
     stream = file(fileName, 'r')
     generatedLCs = yaml.load(stream)
     filterData = generatedLCs[model]
-    peakMag = generatedLCs[model][observeFrameFilter]['Peak Magnitude']
-    peakTime = generatedLCs[model][observeFrameFilter]['Peak Time in Spectra']
+    peakMag = generatedLCs[model][restFrameFilter]['Peak Magnitude']
+    peakTime = generatedLCs[model][restFrameFilter]['Peak Time in Spectra']
     stream.close()
 
     pwd = os.getcwd()
@@ -723,22 +726,22 @@ def generate_single_kcorrection_listing(
             wavelengthArray, fluxArray = extract_spectra_from_file(log, thisFile)
             spRest = syn.ArraySpectrum(wave=wavelengthArray, flux=fluxArray, waveunits='angstrom', fluxunits='flam')
             try:
-                log.debug("attempting to determine the rest %s-magnitude" % (observeFrameFilter,))
+                log.debug("attempting to determine the rest %s-magnitude" % (restFrameFilter,))
                 gRest = calcphot(
                     log,
                     wavelengthArray=wavelengthArray,
                     fluxArray=fluxArray,
-                    obsmode="sdss,%s" % (observeFrameFilter,)
+                    obsmode="sdss,%s" % (restFrameFilter,)
                 )
             except Exception, e:
                 if "Integrated flux is <= 0" in str(e):
-                    log.error("could not determine the rest-magnitude using calcphot - filter, model, time, file %s, %s, %s, %s - failed with this error: %s " % (observeFrameFilter, model, thisTime, thisFile, str(e),))
+                    log.warning("could not determine the rest-magnitude using calcphot - filter, model, time, file %s, %s, %s, %s - failed with this error: %s " % (restFrameFilter, model, thisTime, thisFile, str(e),))
                     continue
                 elif "Spectrum and bandpass do not fully overlap" in str(e):
-                    log.error("could not determine the rest-magnitude using calcphot - filter, model, time, file %s, %s, %s, %s - failed with this error: %s " % (observeFrameFilter, model, thisTime, thisFile, str(e),))
+                    log.warning("could not determine the rest-magnitude using calcphot - filter, model, time, file %s, %s, %s, %s - failed with this error: %s " % (restFrameFilter, model, thisTime, thisFile, str(e),))
                     continue
                 else:
-                    log.warning("could not determine the rest-magnitude using calcphot - filter, model, time, file %s, %s, %s, %s - failed with this error: %s " % (observeFrameFilter, model, thisTime, thisFile, str(e),))
+                    log.warning("could not determine the rest-magnitude using calcphot - filter, model, time, file %s, %s, %s, %s - failed with this error: %s " % (restFrameFilter, model, thisTime, thisFile, str(e),))
                 pass
 
             for thisFilter in filters:
@@ -763,16 +766,16 @@ def generate_single_kcorrection_listing(
                     )
                 except Exception, e:
                     if "Integrated flux is <= 0" in str(e):
-                        log.error("could not determine the magnitude of the object using calcphot - redshift, filter, model %s, %s, %s - failed with this error: %s " % (strRed,thisFilter, model,str(e),))
+                        log.warning("could not determine the magnitude of the object using calcphot - redshift, filter, model %s, %s, %s - failed with this error: %s " % (strRed,thisFilter, model,str(e),))
                         continue
                     elif "Spectrum and bandpass do not fully overlap" in str(e):
-                        log.error("could not determine the magnitude of the object using calcphot - redshift, filter, model %s, %s, %s - failed with this error: %s " % (strRed,thisFilter, model,str(e),))
+                        log.warning("could not determine the magnitude of the object using calcphot - redshift, filter, model %s, %s, %s - failed with this error: %s " % (strRed,thisFilter, model,str(e),))
                         continue
                     else:
                         log.warning("could not determine the magnitude of the object using calcphot - redshift, filter, model %s, %s, %s - failed with this error: %s " % (strRed,thisFilter, model,str(e),))
                     pass
                 kCor = gRest-filterObs
-                kcName = 'K_%s%s' % (observeFrameFilter, thisFilter,)
+                kcName = 'K_%s%s' % (restFrameFilter, thisFilter,)
                 thisKcor = {}
                 thisKcor["Rest Frame Days"] = thisTime
                 thisKcor[kcName] = kCor
@@ -792,7 +795,7 @@ def generate_single_kcorrection_polynomial(
         pathToOutputDirectory,
         redshift,
         ffilter,
-        observeFrameFilter,
+        restFrameFilter,
         kCorPolyOrder=3,
         kCorMinimumDataPoints=3,
         plot=False):
@@ -804,7 +807,7 @@ def generate_single_kcorrection_polynomial(
         - ``pathToOutputDirectory`` -- path to the output directory (provided by the user)
         - ``redshift`` -- the redshift of the k-correction listing to plot
         - ``ffilter`` -- the k-correction rest frame filter
-        - ``observeFrameFilter`` -- the observed frame filter
+        - ``restFrameFilter`` -- the observed frame filter
         - ``kCorPolyOrder`` -- the order of the polynomial to fit
         - ``kCorMinimumDataPoints`` -- Minimum number of datapoints used to generate k-correction curve
         - ``plot`` -- plot the polynomial?
@@ -827,7 +830,7 @@ def generate_single_kcorrection_polynomial(
     fileName = pathToYaml
     stream = file(fileName, 'r')
     yamlList = yaml.load(stream)
-    thisKcor = 'K_%s%s' % (observeFrameFilter, ffilter)
+    thisKcor = 'K_%s%s' % (restFrameFilter, ffilter)
     stream.close()
 
     kCor = []
@@ -838,7 +841,7 @@ def generate_single_kcorrection_polynomial(
             kCor.append(item[thisKcor])
             time.append(item['Rest Frame Days'])
     except Exception, e:
-        log.error("could not generate a k-correction polynomial plot from the file %s:  - failed with this error: %s " % (fileName, str(e),))
+        log.warning("could not generate a k-correction polynomial plot from the file %s:  - failed with this error: %s " % (fileName, str(e),))
         return -1
 
     if len(kCor) < kCorMinimumDataPoints:
@@ -861,7 +864,7 @@ def generate_single_kcorrection_polynomial(
     log.debug('timeArray: %s' % (timeArray,))
     log.debug('kCorArray: %s' % (kCorArray,))
 
-    expand = 500
+    expand = 20
     xMin -= expand
     xMax += expand
 
@@ -872,7 +875,7 @@ def generate_single_kcorrection_polynomial(
     polyDict[redshift] = flatPoly
     dataDict[redshift] = [timeArray, kCorArray]
 
-    title = "k_%s%s at z = %s" % (observeFrameFilter, ffilter, redshift)
+    title = "k_%s%s at z = %s" % (restFrameFilter, ffilter, redshift)
 
     if plot:
         fileName = dp.plot_polynomial(
@@ -904,7 +907,7 @@ def generate_single_kcorrection_polynomial(
 ## AUTHOR : DRYX
 def generate_kcorrection_polynomial_database(
         log,
-        observeFrameFilter,
+        restFrameFilter,
         pathToOutputDirectory,
         kCorPolyOrder=3,
         kCorMinimumDataPoints=3,
@@ -916,7 +919,7 @@ def generate_kcorrection_polynomial_database(
 
     **Key Arguments:**
         - ``log`` -- logger
-        - ``observeFrameFilter`` -- the observed frame filter with which to calculate k-crrections with
+        - ``restFrameFilter`` -- the observed frame filter with which to calculate k-crrections with
         - ``pathToOutputDirectory`` -- path to the output directory (provided by the user)
         - ``kCorPolyOrder`` -- the order of the polynomials to fit
         - ``kCorMinimumDataPoints`` -- Minimum number of datapoints used to generate k-correction curve
@@ -958,7 +961,7 @@ def generate_kcorrection_polynomial_database(
                     pathToOutputDirectory=pathToOutputDirectory,
                     redshift=redshift,
                     ffilter=ffilter,
-                    observeFrameFilter=observeFrameFilter,
+                    restFrameFilter=restFrameFilter,
                     kCorPolyOrder=kCorPolyOrder,
                     kCorMinimumDataPoints=kCorMinimumDataPoints,
                     plot=plot)
