@@ -296,7 +296,7 @@ def plot_sn_discovery_map(log,
     plt.scatter(
         tooFaint,
         tooFaintRedshift,
-        label="""Detected - too faint to constrain as PISN""",
+        label="""Detected - too faint to constrain as transient""",
         s=50,
         c='#dc322f',
         marker='o',
@@ -313,7 +313,7 @@ def plot_sn_discovery_map(log,
     plt.scatter(
         discovered,
         discoveredRedshift,
-        label='Discovered PISN',
+        label='Discovered transient',
         s=50,
         c='#859900',
         marker='o',
@@ -330,7 +330,7 @@ def plot_sn_discovery_map(log,
     plt.scatter(
         shortCampaign,
         shortCampaignRedshift,
-        label="""Detected - campaign to short to constrain as PISN""",
+        label="""Detected - campaign to short to constrain as transient""",
         s=50,
         c='#268bd2',
         marker='o',
@@ -344,7 +344,7 @@ def plot_sn_discovery_map(log,
         verts=None,
         hold=True)
 
-    title = "PISNe Detected Within the Suvrey Year"
+    title = "transients Detected Within the Suvrey Year"
     box = ax.get_position()
     ax.set_position([box.x0, box.y0, box.width * 0.8, box.height])
     # Put a legend to the right of the current axis
@@ -438,16 +438,16 @@ def plot_sn_discovery_ratio_map(log,
     if len(notDiscoveredRedshift) > 0:
         dataDictionary["Undiscovered"] = notDiscoveredRedshift
     if len(tooFaintRedshift) > 0:
-        dataDictionary["Detected - too faint to constrain as PISN"] = tooFaintRedshift
+        dataDictionary["Detected - too faint to constrain as transient"] = tooFaintRedshift
     if len(discoveredRedshift) > 0:
         dataDictionary["Discovered"] = discoveredRedshift
     if len(shortCampaignRedshift) > 0:
-        dataDictionary["Detected - campaign to short to constrain as PISN"] = shortCampaignRedshift
+        dataDictionary["Detected - campaign to short to constrain as transient"] = shortCampaignRedshift
 
     ################ >ACTION(S) ################
     imageLink = dp.plot_polar(
        log,
-       title="Redshift Map of PISNe Simulated within the Survey Volume",
+       title="Redshift Map of transients Simulated within the Survey Volume",
        dataDictionary=dataDictionary,
        pathToOutputPlotsFolder=pathToOutputPlotFolder,
        dataRange=False,
@@ -472,12 +472,12 @@ def determine_sn_rate(
         surveyCadenceSettings,
         surveyArea,
         CCSNRateFraction,
-        PISNToCCSNRateFraction,
+        transientToCCSNRateFraction,
         peakAppMagList,
         snCampaignLengthList,
         extraSurveyConstraints,
         pathToOutputPlotFolder,
-        redshiftLimit=1.0,
+        upperRedshiftLimit=1.0,
         redshiftResolution=0.1
         ):
     """Plot the SFR History as a function of redshift
@@ -490,17 +490,17 @@ def determine_sn_rate(
         - ``surveyArea`` -- the area of the survey considered in square degree
         - ``surveyCadenceSettings`` -- the cadence settings for the survey
         - ``CCSNRateFraction`` -- the fraction of the IMF attributed to the progenitors of CCSN
-        - ``PISNToCCSNRateFraction`` -- the ratio of the PISN rate to the rate of CCSNe
+        - ``transientToCCSNRateFraction`` -- the ratio of the transient rate to the rate of CCSNe
         - ``peakAppMagList`` -- a list of the peak magnitudes for each SN in each filter
         - ``snCampaignLengthList`` -- a list of campaign lengths in each filter
         - ``extraSurveyConstraints`` -- some extra survey constraints
         - ``pathToOutputPlotDirectory`` -- path to add plots to
-        - ``redshiftLimit`` -- the redshist limit out to which to determine the rate
+        - ``upperRedshiftLimit`` -- the redshist limit out to which to determine the rate
         - ``redshiftResolution`` -- the redshist resolution ued to determine the rate
 
     **Return:**
         - ``imageLink`` -- MD link to the output plot
-        - ``totalRate`` -- the final PISN rate calculated
+        - ``totalRate`` -- the final transient rate calculated
     """
     ################ > IMPORTS ################
     ## STANDARD LIB ##
@@ -514,13 +514,13 @@ def determine_sn_rate(
     filters = ['g', 'r', 'i', 'z']
 
     sdssArea = 5713.
-    sdssSFRRedshiftLimit = 0.033
+    sdssSFRupperRedshiftLimit = 0.033
     sdssSFR = 14787.21
     CCSNRateFraction = 0.007
-    PISNToCCSNRateFraction = 1./10000.
-    PISNRateFraction = CCSNRateFraction*PISNToCCSNRateFraction
+    transientToCCSNRateFraction = 1./10000.
+    transientRateFraction = CCSNRateFraction*transientToCCSNRateFraction
 
-    anchor = redshiftResolution/sdssSFRRedshiftLimit
+    anchor = redshiftResolution/sdssSFRupperRedshiftLimit
     normaiseSFR = sdssSFR*anchor**3
     areaRatio = surveyArea/sdssArea
     #log.info('normaiseSFR %s' % (normaiseSFR,))
@@ -530,9 +530,9 @@ def determine_sn_rate(
 
     multiplier = int(1/redshiftResolution)
     redshiftResolution = int(redshiftResolution*multiplier)
-    redshiftLimit = int(redshiftLimit*multiplier)
+    upperRedshiftLimit = int(upperRedshiftLimit*multiplier)
 
-    shellPISNRateDensityList = []
+    shelltransientRateDensityList = []
     shellRedshiftList = []
     discoveryRedshiftList = []
     discoveryFractionList = []
@@ -540,10 +540,10 @@ def determine_sn_rate(
     tooFaintFractionList = []
     shortCampaignRedshiftList = []
     shortCampaignFractionList = []
-    PISNShellRateList = []
+    transientShellRateList = []
     tooFaintShellRateList = []
     shortCampaignShellRateList = []
-    for shellRedshift in range(redshiftResolution, redshiftLimit, redshiftResolution):
+    for shellRedshift in range(redshiftResolution, upperRedshiftLimit, redshiftResolution):
         shellRedshift = float(shellRedshift)/float(multiplier)
         shellWidth = float(redshiftResolution)/float(multiplier)
         shellMiddle = shellRedshift - shellWidth/2.
@@ -555,12 +555,12 @@ def determine_sn_rate(
         else:
             shellVolume = da.convert_redshift_to_distance(shellRedshift)['dl_mpc']**3
         shellSFRDensity = (SFH/anchor)*normaiseSFR*(shellVolume/anchorVolume)
-        shellPISNRateDensity = shellSFRDensity*PISNRateFraction
-        shellPISNRateDensity = shellPISNRateDensity*areaRatio
+        shelltransientRateDensity = shellSFRDensity*transientRateFraction
+        shelltransientRateDensity = shelltransientRateDensity*areaRatio
         timeDilation = 1./(1.+shellMiddle)
-        shellPISNRateDensity = shellPISNRateDensity*timeDilation
-        # log.info('shellPISNRateDensity %s' % (shellPISNRateDensity,))
-        shellPISNRateDensityList.append(shellPISNRateDensity)
+        shelltransientRateDensity = shelltransientRateDensity*timeDilation
+        # log.info('shelltransientRateDensity %s' % (shelltransientRateDensity,))
+        shelltransientRateDensityList.append(shelltransientRateDensity)
         shellRedshiftList.append(shellMiddle)
 
         discoveryFraction, tooFaintFraction, shortCampaignFraction = calculate_fraction_of_sn_discovered(log, surveyCadenceSettings, snSurveyDiscoveryTimes, redshifts, peakAppMagList, snCampaignLengthList, extraSurveyConstraints, shellRedshiftBottom, shellRedshift)
@@ -575,10 +575,10 @@ def determine_sn_rate(
         shortCampaignRedshiftList.append(shellMiddle)
         shortCampaignFractionList.append(shortCampaignFraction)
 
-        PISNShellRate = discoveryFraction*shellPISNRateDensity
-        tooFaintShellRate = tooFaintFraction*shellPISNRateDensity
-        shortCampaignShellRate = shortCampaignFraction*shellPISNRateDensity
-        PISNShellRateList.append(PISNShellRate)
+        transientShellRate = discoveryFraction*shelltransientRateDensity
+        tooFaintShellRate = tooFaintFraction*shelltransientRateDensity
+        shortCampaignShellRate = shortCampaignFraction*shelltransientRateDensity
+        transientShellRateList.append(transientShellRate)
         tooFaintShellRateList.append(tooFaintShellRate)
         shortCampaignShellRateList.append(shortCampaignShellRate)
 
@@ -603,23 +603,23 @@ def determine_sn_rate(
         pleasePlot = True
         thisPoly = np.polyfit(tooFaintRedshiftListArray, tooFaintFractionListArray, 12)
         tooFaintRateCurve = np.poly1d(thisPoly)
-        #polynomialDict["Detected - too faint to constrain as PISN"] = tooFaintRateCurve
-        orginalDataDictionary["Detected - too faint to constrain as PISN"] = [tooFaintRedshiftListArray, tooFaintFractionListArray]
+        #polynomialDict["Detected - too faint to constrain as transient"] = tooFaintRateCurve
+        orginalDataDictionary["Detected - too faint to constrain as transient"] = [tooFaintRedshiftListArray, tooFaintFractionListArray]
     else:
         tooFaintRateCurve = False
     if len(shortCampaignRedshiftListArray) > 0:
         pleasePlot = True
         thisPoly = np.polyfit(shortCampaignRedshiftListArray, shortCampaignFractionListArray, 12)
         shortCampaignRateCurve = np.poly1d(thisPoly)
-        #polynomialDict["Detected - campaign to short to constrain as PISN"] = shortCampaignRateCurve
-        orginalDataDictionary["Detected - campaign to short to constrain as PISN"] = [shortCampaignRedshiftListArray, shortCampaignFractionListArray]
+        #polynomialDict["Detected - campaign to short to constrain as transient"] = shortCampaignRateCurve
+        orginalDataDictionary["Detected - campaign to short to constrain as transient"] = [shortCampaignRedshiftListArray, shortCampaignFractionListArray]
     else:
         shortCampaignRateCurve = False
 
     if pleasePlot:
         imageLink = dp.plot_polynomial(
                 log,
-                title='PS1-PISN Survey - Precentage of PISN Detected',
+                title='PS1-transient Survey - Precentage of transient Detected',
                 polynomialDict=polynomialDict,
                 orginalDataDictionary=orginalDataDictionary,
                 pathToOutputPlotsFolder=pathToOutputPlotFolder,
@@ -634,18 +634,18 @@ def determine_sn_rate(
     else:
         imageLink = ""
 
-    shellPISNRateDensityArray = np.array(shellPISNRateDensityList)
+    shelltransientRateDensityArray = np.array(shelltransientRateDensityList)
     shellRedshiftArray = np.array(shellRedshiftList)
     # log.info('shellRedshiftArray %s' % (shellRedshiftArray,))
-    # log.info('shellPISNRateDensityArray %s' % (shellPISNRateDensityArray,))
-    thisPoly = np.polyfit(shellRedshiftArray, shellPISNRateDensityArray, 3)
-    PISNRateCurve = np.poly1d(thisPoly)
+    # log.info('shelltransientRateDensityArray %s' % (shelltransientRateDensityArray,))
+    thisPoly = np.polyfit(shellRedshiftArray, shelltransientRateDensityArray, 3)
+    transientRateCurve = np.poly1d(thisPoly)
     # log.info('flat %s' % (flatPoly,))
-    polynomialDict = { "PISN Rate" : PISNRateCurve }
-    orginalDataDictionary = { "PISN Rate" : [shellRedshiftArray, shellPISNRateDensityArray] }
+    polynomialDict = { "transient Rate" : transientRateCurve }
+    orginalDataDictionary = { "transient Rate" : [shellRedshiftArray, shelltransientRateDensityArray] }
     imageLink = dp.plot_polynomial(
             log,
-            title='PS1 MDF PISN Rate Density',
+            title='PS1 MDF transient Rate Density',
             polynomialDict=polynomialDict,
             orginalDataDictionary=orginalDataDictionary,
             pathToOutputPlotsFolder=pathToOutputPlotFolder,
@@ -662,27 +662,27 @@ def determine_sn_rate(
     pleasePlot = False
     if discoveryRateCurve:
         pleasePlot = True
-        discoveredPISNCurve = PISNRateCurve*discoveryRateCurve
-        discoveredPISNCurve = np.poly1d(discoveredPISNCurve)
-        #polynomialDict['Discovered PISN Rate'] = discoveredPISNCurve
-        orginalDataDictionary['Discovered PISN Rate'] = [shellRedshiftArray, shellPISNRateDensityArray*discoveryFractionListArray]
+        discoveredtransientCurve = transientRateCurve*discoveryRateCurve
+        discoveredtransientCurve = np.poly1d(discoveredtransientCurve)
+        #polynomialDict['Discovered transient Rate'] = discoveredtransientCurve
+        orginalDataDictionary['Discovered transient Rate'] = [shellRedshiftArray, shelltransientRateDensityArray*discoveryFractionListArray]
     if tooFaintRateCurve:
         pleasePlot = True
-        tooFaintPISNCurve = PISNRateCurve*tooFaintRateCurve
-        tooFaintPISNCurve = np.poly1d(tooFaintPISNCurve)
-        #polynomialDict["Detected - too faint to constrain as PISN"] = tooFaintPISNCurve
-        orginalDataDictionary["Detected - too faint to constrain as PISN"] = [shellRedshiftArray, shellPISNRateDensityArray*tooFaintFractionListArray]
+        tooFainttransientCurve = transientRateCurve*tooFaintRateCurve
+        tooFainttransientCurve = np.poly1d(tooFainttransientCurve)
+        #polynomialDict["Detected - too faint to constrain as transient"] = tooFainttransientCurve
+        orginalDataDictionary["Detected - too faint to constrain as transient"] = [shellRedshiftArray, shelltransientRateDensityArray*tooFaintFractionListArray]
     if shortCampaignRateCurve:
         pleasePlot = True
-        shortCampaignPISNCurve = PISNRateCurve*shortCampaignRateCurve
-        shortCampaignPISNCurve = np.poly1d(shortCampaignPISNCurve)
-        #polynomialDict["Detected - campaign to short to constrain as PISN"] = shortCampaignPISNCurve
-        orginalDataDictionary["Detected - campaign to short to constrain as PISN"] = [shellRedshiftArray, shellPISNRateDensityArray*shortCampaignFractionListArray]
+        shortCampaigntransientCurve = transientRateCurve*shortCampaignRateCurve
+        shortCampaigntransientCurve = np.poly1d(shortCampaigntransientCurve)
+        #polynomialDict["Detected - campaign to short to constrain as transient"] = shortCampaigntransientCurve
+        orginalDataDictionary["Detected - campaign to short to constrain as transient"] = [shellRedshiftArray, shelltransientRateDensityArray*shortCampaignFractionListArray]
 
     if pleasePlot:
         imageLink = dp.plot_polynomial(
                 log,
-                title='PS1-PISN Survey - Relative Detected Rates',
+                title='PS1-transient Survey - Relative Detected Rates',
                 polynomialDict=polynomialDict,
                 orginalDataDictionary=orginalDataDictionary,
                 pathToOutputPlotsFolder=pathToOutputPlotFolder,
@@ -698,7 +698,7 @@ def determine_sn_rate(
         imageLink = ""
 
     totalRate = 0.
-    for item in PISNShellRateList:
+    for item in transientShellRateList:
         totalRate += item
 
     tooFaintRate = 0.
@@ -767,8 +767,9 @@ def log_the_survey_settings(
     relativeRatesSet = yamlContent["Relative Rate Set to Use"]
     relativeSNRates = yamlContent["Relative SN Rates"][relativeRatesSet]
     #log.debug('relativeSNRates %s' % (relativeSNRates,))
-    redshiftLimit = yamlContent["Volume Limit Redshift"]
-    #log.debug('redshiftLimit %s' % (redshiftLimit,))
+    lowerRedshiftLimit = yamlContent["Lower Redshift Limit"]
+    upperRedshiftLimit = yamlContent["Upper Redshift Limit"]
+    #log.debug('upperRedshiftLimit %s' % (upperRedshiftLimit,))
     redshiftResolution = yamlContent["Redshift Resolution"]
 
     extinctionSettings = yamlContent["Extinctions"]
@@ -794,8 +795,8 @@ def log_the_survey_settings(
     observableFraction = surveyCadenceSettings["Observable Fraction of Year"]
     extinctionConstant = extinctionSettings["constant E(b-v)"]
     CCSNRateFraction = yamlContent["CCSN Progenitor Population Fraction of IMF"]
-    PISNToCCSNRateFraction = yamlContent["PISN to CCSN Ratio"]
-    observeFrameFilter = yamlContent["Observed Frame Filter for K-corrections"]
+    transientToCCSNRateFraction = yamlContent["Transient to CCSN Ratio"]
+    restFrameFilter = yamlContent["Rest Frame Filter for K-corrections"]
     peakMagLimit = extraSurveyConstraints["Faint-Limit of Peak Magnitude"]
     campaignLengthLimit = extraSurveyConstraints["Observable for at least ? number of days"]
 
@@ -809,28 +810,28 @@ The *%s*-band liming magnitudes of this simulated survey are:
 
 | Filter | Magnitude |
 |:---|:----|
-""" % (now, observeFrameFilter)
+""" % (now, restFrameFilter)
     for k, v in limitingMags.iteritems():
         settings_log += """| %s | %s |\n""" % (k,v,)
     settings_log += """
 
-A total of **%s** PISNe where simulated in the survey, out to a **redshift of %s**. A constant galactic extinction of `E(B-V) = %s` is used (the mean extinction of the 10 PS1 Medimum Deep Fields). The MDFs are visible for a fraction of %s of the survey year and the typical fraction of survey time lost to weather of %s is accounted for. Here are the relative rates and peak magnitude distributions of the SN used in the survey:
+A total of **%s** transients where simulated in the survey, within a **redshift-range of %s-%s**. A constant galactic extinction of `E(B-V) = %s` is used (the mean extinction of the 10 PS1 Medimum Deep Fields). The MDFs are visible for a fraction of %s of the survey year and the typical fraction of survey time lost to weather of %s is accounted for. Here are the relative rates and peak magnitude distributions of the SN used in the survey:
 
 | SN Type | Relative Rate | Peak Magnitude | Sigma Peak |
 |:---|:---|:---|:---|
-""" % (sampleNumber, redshiftLimit, extinctionConstant, observableFraction, weatherLossFraction,)
+""" % (sampleNumber, lowerRedshiftLimit, upperRedshiftLimit, extinctionConstant, observableFraction, weatherLossFraction,)
     for k, v in peakMagnitudeDistributions['magnitude'].iteritems():
         settings_log += """| %s | %s | %s | %s |\n""" % (k, relativeSNRates[k], v, peakMagnitudeDistributions['sigma'][k])
     settings_log += """
 
-If a PISN is detected by the simulated survey, extra constraints are placed upon the detected object to secure positive identification as a PISN.
+If a transient is detected by the simulated survey, extra constraints are placed upon the detected object to secure positive identification as the object.
 
 1. The peak apparent magnitude of the object must be brighter than **%s mag**
 2. The object must be detectable for long enough to complete a follow-up campaign of longer than **%s days** within 1 survey year with any single filter.
 
-The PISN rate for the survey volume is estimated by assuming a rate of **%s** times that of the CCSN rate (itself a fraction of **%s** of the total SFR).
+The transient rate for the survey volume is estimated by assuming a rate of **%s** times that of the CCSN rate (itself a fraction of **%s** of the total SFR).
 
-""" % (peakMagLimit, campaignLengthLimit, PISNToCCSNRateFraction, CCSNRateFraction)
+""" % (peakMagLimit, campaignLengthLimit, transientToCCSNRateFraction, CCSNRateFraction)
     return settings_log
 
 
@@ -927,11 +928,11 @@ def calculate_fraction_of_sn_discovered(
     if len(notDiscoveredRedshift) > 0:
         dataDictionary["Undiscovered"] = notDiscoveredRedshift
     if len(tooFaintRedshift) > 0:
-        dataDictionary["Detected - too faint to constrain as PISN"] = tooFaintRedshift
+        dataDictionary["Detected - too faint to constrain as transient"] = tooFaintRedshift
     if len(discoveredRedshift) > 0:
         dataDictionary["Discovered"] = discoveredRedshift
     if len(shortCampaignRedshift) > 0:
-        dataDictionary["Detected - campaign to short to constrain as PISN"] = shortCampaignRedshift
+        dataDictionary["Detected - campaign to short to constrain as transient"] = shortCampaignRedshift
 
     totalWithinVolume = float(len(discoveredRedshift)+len(notDiscoveredRedshift)+len(tooFaintRedshift)+len(shortCampaignRedshift))
 
